Installation
============

Pylint can be installed:

- :ref:`As a command line tool <installation>`
- :ref:`Integrated in your editor/ide <ide-integration>`
- :ref:`As a pre-commit hook <pre-commit-integration>`
- :ref:`For multiple python interpreters in your continuous integration <continuous-integration>`

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :hidden:

   command_line_installation.rst
   ide_integration/index
   pre-commit-integration.rst
   with-multiple-interpreters.rst
   badge
   upgrading_pylint.rst
